@@ -5,7 +5,7 @@ source 'https://rubygems.org'
 gemspec
 
 group :maintenance, optional: true do
-	gem "bake-bundler"
+	gem "bake-gem"
 	gem "bake-modernize"
 	
 	gem "utopia-project"
