@@ -34,4 +34,20 @@ RSpec.describe Async::Clock do
 	it "can get current offset" do
 		expect(Async::Clock.now).to be_kind_of Float
 	end
+	
+	it "can accumulate durations" do
+		2.times do
+			subject.start!
+			sleep(0.1)
+			subject.stop!
+		end
+		
+		expect(subject.total).to be_within(0.02 * Q).of(0.2)
+	end
+	
+	context 'with given total' do
+		subject {described_class.new(1.5)}
+		
+		it{is_expected.to have_attributes(total: 1.5)}
+	end
 end
